@@ -1,3 +1,5 @@
+#[forbid(unsafe_code)]
+#[warn(missing_docs)]
 mod error;
 mod jargons;
 mod keys;
